@@ -53,20 +53,14 @@ bool KapmanParser::parse(QIODevice *input)
 
     return true;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-bool KapmanParser::characters(const QStringRef &ch)
-#else
+
 bool KapmanParser::characters(const QStringView &ch)
-#endif
 {
     m_buffer = ch.toString();
     return true;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-bool KapmanParser::startElement(const QStringRef &namespaceURI, const QStringRef &localName, const QStringRef &qName, const QXmlStreamAttributes &atts)
-#else
+
 bool KapmanParser::startElement(const QStringView &namespaceURI, const QStringView &localName, const QStringView &qName, const QXmlStreamAttributes &atts)
-#endif
 {
     Q_UNUSED(namespaceURI)
     Q_UNUSED(localName)
@@ -150,11 +144,8 @@ bool KapmanParser::startElement(const QStringView &namespaceURI, const QStringVi
 
     return true;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-bool KapmanParser::endElement(const QStringRef &namespaceURI, const QStringRef &localName, const QStringRef &qName)
-#else
+
 bool KapmanParser::endElement(const QStringView &namespaceURI, const QStringView &localName, const QStringView &qName)
-#endif
 {
     Q_UNUSED(namespaceURI)
     Q_UNUSED(localName)
